Index: content/browser/renderer_host/render_widget_host_view_aura_unittest.cc |
diff --git a/content/browser/renderer_host/render_widget_host_view_aura_unittest.cc b/content/browser/renderer_host/render_widget_host_view_aura_unittest.cc |
index 0da99fbab737c560a75ea2eaf40735879c553bfa..a61f4e2413fcd7233438ff30f7e5e6eebf51ef18 100644 |
--- a/content/browser/renderer_host/render_widget_host_view_aura_unittest.cc |
+++ b/content/browser/renderer_host/render_widget_host_view_aura_unittest.cc |
@@ -1231,8 +1231,8 @@ TEST_F(RenderWidgetHostViewAuraTest, FinishCompositionByMouse) { |
EXPECT_EQ(2U, sink_->message_count()); |
if (sink_->message_count() == 2) { |
- // Verify mouse event happens after the confirm-composition event. |
- EXPECT_EQ(InputMsg_ImeConfirmComposition::ID, |
+ // Verify mouse event happens after the commit-text event. |
+ EXPECT_EQ(InputMsg_ImeFinishComposingText::ID, |
sink_->GetMessageAt(0)->type()); |
EXPECT_EQ(InputMsg_HandleInputEvent::ID, |
sink_->GetMessageAt(1)->type()); |
@@ -4355,11 +4355,11 @@ TEST_F(InputMethodResultAuraTest, ConfirmCompositionText) { |
ActivateViewForTextInputManager(views_[index], ui::TEXT_INPUT_TYPE_TEXT); |
SetHasCompositionTextToTrue(); |
EXPECT_TRUE(!!RunAndReturnIPCSent(ime_call, processes_[index], |
- InputMsg_ImeConfirmComposition::ID)); |
+ InputMsg_ImeFinishComposingText::ID)); |
} |
} |
-// This test is for ui::TextInputClient::ConfirmCompositionText. |
+// This test is for ui::TextInputClient::ClearCompositionText. |
TEST_F(InputMethodResultAuraTest, ClearCompositionText) { |
base::Closure ime_call = |
base::Bind(&ui::TextInputClient::ClearCompositionText, |
@@ -4380,7 +4380,7 @@ TEST_F(InputMethodResultAuraTest, InsertText) { |
for (auto index : active_view_sequence_) { |
ActivateViewForTextInputManager(views_[index], ui::TEXT_INPUT_TYPE_TEXT); |
EXPECT_TRUE(!!RunAndReturnIPCSent(ime_call, processes_[index], |
- InputMsg_ImeConfirmComposition::ID)); |
+ InputMsg_ImeCommitText::ID)); |
} |
} |
@@ -4395,7 +4395,7 @@ TEST_F(InputMethodResultAuraTest, FinishImeCompositionSession) { |
SetHasCompositionTextToTrue(); |
EXPECT_TRUE(!!RunAndReturnIPCSent(ime_finish_session_call, |
processes_[index], |
- InputMsg_ImeConfirmComposition::ID)); |
+ InputMsg_ImeFinishComposingText::ID)); |
} |
} |